@@ -1,5 +1,7 @@
 from ish_report import ish_report
+import logging
 
+LOG = logging.getLogger('ish_parser')
 
 class ish_parser(object):
 
@@ -14,14 +16,13 @@ class ish_parser(object):
       if len(line) < 10:
         continue
 
-      report = ish_report()
       try:
+        report = ish_report()
         report.loads(line)
-      except BaseException, err:
-        ''' print line '''
-        #raise err
-
-      self._reports.append(report)
+        self._reports.append(report)
+      except BaseException, exp:
+        ''' don't complain TOO much '''
+        LOG.warn('unable to load report, error: %s' % exp)
 
   def get_reports(self):
     ''' return a list of all the reports '''
